==> kubernetes-model-apiextensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceColumnDefinitionBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomResourceColumnDefinitionBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionBuilder>{
  public CustomResourceColumnDefinitionBuilder() {
    this(false);
  }
  public CustomResourceColumnDefinitionBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomResourceColumnDefinition(), validationEnabled);
  }
  public CustomResourceColumnDefinitionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceColumnDefinitionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomResourceColumnDefinition(), validationEnabled);
  }
  public CustomResourceColumnDefinitionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition instance) {
    this(fluent, instance, false);
  }
  public CustomResourceColumnDefinitionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withFormat(instance.getFormat()); 
    fluent.withJsonPath(instance.getJsonPath()); 
    fluent.withName(instance.getName()); 
    fluent.withPriority(instance.getPriority()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceColumnDefinitionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition instance) {
    this(instance,false);
  }
  public CustomResourceColumnDefinitionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withFormat(instance.getFormat()); 
    this.withJsonPath(instance.getJsonPath()); 
    this.withName(instance.getName()); 
    this.withPriority(instance.getPriority()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition build() {
    CustomResourceColumnDefinition buildable = new CustomResourceColumnDefinition(fluent.getDescription(),fluent.getFormat(),fluent.getJsonPath(),fluent.getName(),fluent.getPriority(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceColumnDefinitionBuilder that = (CustomResourceColumnDefinitionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-apiextensions-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceColumnDefinitionBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomResourceColumnDefinitionBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionBuilder>{
  public CustomResourceColumnDefinitionBuilder() {
    this(false);
  }
  public CustomResourceColumnDefinitionBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomResourceColumnDefinition(), validationEnabled);
  }
  public CustomResourceColumnDefinitionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceColumnDefinitionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomResourceColumnDefinition(), validationEnabled);
  }
  public CustomResourceColumnDefinitionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition instance) {
    this(fluent, instance, false);
  }
  public CustomResourceColumnDefinitionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withFormat(instance.getFormat()); 
    fluent.withJsonPath(instance.getJsonPath()); 
    fluent.withName(instance.getName()); 
    fluent.withPriority(instance.getPriority()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceColumnDefinitionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition instance) {
    this(instance,false);
  }
  public CustomResourceColumnDefinitionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withFormat(instance.getFormat()); 
    this.withJsonPath(instance.getJsonPath()); 
    this.withName(instance.getName()); 
    this.withPriority(instance.getPriority()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinitionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceColumnDefinition build() {
    CustomResourceColumnDefinition buildable = new CustomResourceColumnDefinition(fluent.getDescription(),fluent.getFormat(),fluent.getJsonPath(),fluent.getName(),fluent.getPriority(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceColumnDefinitionBuilder that = (CustomResourceColumnDefinitionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
